@@ -1,9 +1,10 @@
 package Class::constr ;
-$VERSION = 1.6 ;
+$VERSION = 1.61 ;
 
 ; use 5.006_001
 ; use strict
 ; use Carp
+; $Carp::Internal{+__PACKAGE__}++
 
 ; sub import
    { my ($pkg, @args) = @_
@@ -50,9 +51,13 @@ __END__
 
 Class::constr - Pragma to implement constructor methods
 
-=head1 VERSION 1.6
+=head1 VERSION 1.61
 
-Included in OOTools 1.6 distribution. The distribution includes:
+Included in OOTools 1.61 distribution.
+
+The latest versions changes are reported in the F<Changes> file in this distribution.
+
+The distribution includes:
 
 =over
 
@@ -78,6 +83,29 @@ Pragma to implement groups of properties accessors with options
 
 =back
 
+=head1 INSTALLATION
+
+=over
+
+=item Prerequisites
+
+    Perl version >= 5.6.1
+
+=item CPAN
+
+    perl -MCPAN -e 'install OOTools'
+
+=item Standard installation
+
+From the directory where this file is located, type:
+
+    perl Makefile.PL
+    make
+    make test
+    make install
+
+=back
+
 =head1 SYNOPSIS
 
 =head2 Class
@@ -108,52 +136,27 @@ This pragma easily implements constructor methods for your class. Use it with C<
 
 You can completely avoid to write the constructor by just using it and eventually declaring the name and the init methods to call.
 
-B<IMPORTANT NOTE>: If you write any script that rely on this module, you better send me an e-mail so I will inform you in advance about eventual planned changes, new releases, and other relevant issues that could speed-up your work. (see also L<"CONTRIBUTION">) 
+B<IMPORTANT NOTE>: If you write any script that rely on this module, you better send me an e-mail so I will inform you in advance about eventual planned changes, new releases, and other relevant issues that could speed-up your work.
 
 =head2 Examples
 
 If you want to see some working example of this distribution, take a look at the source of the modules of the F<CGI-Application-Plus> distribution, and the F<Template-Magic> distribution.
 
-=head1 INSTALLATION
+=head1 OPTIONS
 
-=over
-
-=item Prerequisites
-
-    Perl version >= 5.6.1
-
-=item CPAN
-
-    perl -MCPAN -e 'install OOTools'
-
-=item Standard installation
-
-From the directory where this file is located, type:
-
-    perl Makefile.PL
-    make
-    make test
-    make install
-
-=back
-
-=head2 OPTIONS
-
-=over
-
-=item name
+=head2 name
 
 The name of the constructor method. If you omit this option the 'new' name will be used by default.
 
-=item no_strict
+=head2 no_strict
 
 With C<no_strict> option set to a true value, the constructor method accepts and sets also unknown properties (i.e. not predeclared). You have to access the unknown properties without any accessor method. All the other options will work as expected. Without this option the constructor will croak if any property does not have an accessor method.
 
-=item pre_process
+=head2 pre_process
 
 You can set a code reference to preprocess @_.
 
-The original <@_> is passed to the referenced pre_process CODE. Modify C<@_> in the CODE to change the actual input value.
+The original C<@_> is passed to the referenced pre_process CODE. Modify C<@_> in the CODE to change the actual input value.
 
     # This code will transform the @_ on input
     # if it's passed a ref to an ARRAY
@@ -169,19 +172,15 @@ The original <@_> is passed to the referenced pre_process CODE. Modify C<@_> in
                          }
         }
 
-=item init
+=head2 init
 
 Use this option if you want to call other methods in your class to further initialize the object. You can group methods by passing a reference to an array containing the method names.
 
 After the assignation and validation of the properties, the initialization methods in the C<init> option will be called. Each init method will receive the blessed object passed in C<$_[0]> and the other parameters in the remaining C<@_>.
 
-=back
-
 =head1 SUPPORT and FEEDBACK
 
-I would like to have just a line of feedback from everybody who tries or actually uses this module. PLEASE, write me any comment, suggestion or request. ;-)
-
-More information at http://perl.4pro.net/?Class::constr.
+If you need support or if you want just to send me some feedback or request, please use this link: http://perl.4pro.net/?Class::constr.
 
 =head1 AUTHOR and COPYRIGHT
 
@@ -193,7 +192,3 @@ All Rights Reserved. This module is free software. It may be used, redistributed
 
 Thanks to Juerd Waalboer (http://search.cpan.org/author/JUERD) that with its I<Attribute::Property> inspired the creation of this distribution.
 
-=head1 CONTRIBUTION
-
-I always answer to each and all the message i receive from users, but I have almost no time to find, install and organize a mailing list software that could improve a lot the support to people that use my modules. Besides I have too little time to write more detailed documentation, more examples and tests. Your contribution would be precious, so if you can and want to help, just contact me. Thank you in advance.
-
